@@ -1,25 +1,22 @@
 from . import resources
 from .all_components import all_components
 from .deployment import deployment
-from .tokens import token_util
-from .simple_jwt import simple_jwt
-from importlib_metadata import version
-from .email import email
-from .chat import chat
-from .django_willing_zg import django_willing_zg
 from .get_env import get_env_util
-
+from .tokens import token_util
+from importlib_metadata import version
+from .django_willing_zg import django_willing_zg
+from .google_analytics import google_analytics
+from .chat import chat
 
 __all__ = [
     "all_components",
     "resources",
+    "get_env_util",
     "deployment",
     "token_util",
-    "simple_jwt",
-    "email",
-    "chat",
     "django_willing_zg",
-    "get_env_util",
+    "google_analytics",
+    "chat"
 ]
 
 __version__ = version("willing_zg")
