@@ -2,11 +2,9 @@ from zygoat.components import Component
 from zygoat.components.backend.reformat import reformat
 
 from .deployment import deployment
-from .email import email
-from .simple_jwt import simple_jwt
 from .tokens import token_util
-from .chat import chat
 from .django_willing_zg import django_willing_zg
+from .google_analytics import google_analytics
 from .get_env import get_env_util
 
 
@@ -15,5 +13,12 @@ class AllComponents(Component):
 
 
 all_components = AllComponents(
-    sub_components=[deployment, email, simple_jwt, token_util, reformat, chat, django_willing_zg, get_env_util]
+    sub_components=[
+        deployment,
+        token_util,
+        reformat,
+        get_env_util,
+        django_willing_zg,
+        google_analytics,
+    ]
 )
