@@ -7,6 +7,8 @@ from zygoat.constants import Projects
 from zygoat.utils.printing import log
 from zygoat.config import Config
 
+ECR_REPO_PREFIX = "818831340115.dkr.ecr.us-east-1.amazonaws.com"
+
 
 def main(args):
     config = Config()
@@ -19,8 +21,19 @@ def main(args):
             run(["zappa", "manage", args.environment, "migrate"])
 
         with use_dir(Projects.FRONTEND):
-            log.info(f"Updating {args.environment} frontend")
-            run(["eb", "deploy", f"{config.name}-{args.environment}"])
+            log.info("Building frontend")
+            image_name = f"{config.name}-frontend"
+            latest = f"{image_name}:latest"
+            run(["docker", "build", "-t", f"{image_name}", "."])
+            run(
+                [
+                    "docker",
+                    "tag",
+                    f"{config.name}-frontend:latest",
+                    f"{ECR_REPO_PREFIX}/{latest}",
+                ]
+            )
+            run(["docker", "push", f"{ECR_REPO_PREFIX}/{latest}"])
 
 
 if __name__ == "__main__":
